## Install package
### macOS
```
pip install screen-lens
```

### Ubuntu
```
pipx install screen-lens
```

## Prerequisites
### macOS
Install `curl` from homebrew
```
brew install curl
```
Install `jq` from homebrew
```
brew install jq
```

### Ubuntu
Install `curl`
```
apt install curl
```
Install `jq`
```
apt install jq
```

## Run package
```
$ screen-lens
```

## Report a bug or raise a feature request
✉️ `connectwithme@sanchittanwar7.in`
